@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::AutoMetaResourcesPrefixed;
 
-our $VERSION = '0.27'; #VERSION
+our $VERSION = '0.28'; #VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::AutoMetaResources';
@@ -50,9 +50,7 @@ sub _build__bugtracker_map {
             web => 'https://rt.cpan.org/Public/Dist/Display.html?Name=%{dist}',
             mailto => 'bug-%{dist}@rt.cpan.org',
         },
-        github => {
-            web => 'https://github.com/%{user}/perl-%{lcdist}/issues',
-        }
+        github => { web => 'https://github.com/%{user}/perl-%{lcdist}/issues', }
     };
 }
 
@@ -68,7 +66,7 @@ Dist::Zilla::Plugin::AutoMetaResourcesPrefixed
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 AUTHOR
 
