@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.27'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -49,12 +49,14 @@ use Dist::Zilla::Plugin::PodSyntaxTests;
 use Dist::Zilla::Plugin::PodCoverageTests;
 use Dist::Zilla::Plugin::Test::Portability;
 use Dist::Zilla::Plugin::Test::Version;
+use Dist::Zilla::Plugin::TravisYML;
 
 use Dist::Zilla::Plugin::MinimumPerl;
 use Dist::Zilla::Plugin::MetaNoIndex;
 use Dist::Zilla::Plugin::MetaProvides::Package;
 use Dist::Zilla::Plugin::MetaYAML;
 use Dist::Zilla::Plugin::MetaJSON;
+use Dist::Zilla::Plugin::Git::CommitBuild;
 
 use Dist::Zilla::Plugin::PerlTidy;
 use Dist::Zilla::Plugin::MakeMaker::Awesome;
@@ -102,6 +104,14 @@ has no_git => (
 );
 
 
+has no_commitbuild => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub { $_[0]->payload->{no_commitbuild} },
+);
+
+
 has version_regexp => (
     is      => 'ro',
     isa     => 'Str',
@@ -276,8 +286,11 @@ sub configure {
             : 'ContributorsFromGit'
         ),
 
-        'PruneCruft',      # core
-        'ManifestSkip',    # core
+        [
+            'PruneCruft' => { except => '\.travis.yml', }    # core
+        ],
+
+        'ManifestSkip',                                      # core
 
         # file munging
         'OurPkgVersion',
@@ -292,15 +305,23 @@ sub configure {
         # generated distribution files
         'ReadmeAnyFromPod',    # in build dir
         [
-            ReadmeAnyFromPod => ReadmeInRoot =>
-              {                # also generate in root for github, etc.
+            ReadmeAnyFromPod => ReadmePodInRoot =>
+              {    # also generate README.pod in root for github, etc.
                 type     => 'pod',
                 filename => 'README.pod',
                 location => 'root',
               }
         ],
+        [
+            ReadmeAnyFromPod => ReadmeMarkdownInRoot =>
+              { # also generate README.md (github friendly) file for github, etc.
+                type     => 'markdown',
+                filename => 'README.md',
+                location => 'root',
+              }
+        ],
 
-        'License',             # core
+        'License',    # core
 
         # generated t/ tests
         [ 'Test::Compile'        => { fake_home       => 1 } ],
@@ -313,11 +334,13 @@ sub configure {
             ? [
                 'GatherDir' => {
                     exclude_filename => $self->exclude_filename,
+                    include_dotfiles => 1,
                 },
               ]    # core
             : [
                 'Git::GatherDir' => {
                     exclude_filename => $self->exclude_filename,
+                    include_dotfiles => 1,
                 },
             ]
         ),
@@ -341,11 +364,7 @@ sub configure {
             $self->no_critic ? ()
             : ('Test::Perl::Critic')
         ),
-        [
-            'Test::Kwalitee::Extra' => {
-                has_corpus => 0,
-            },
-        ],
+        [ 'Test::Kwalitee::Extra' => { has_corpus => 0, }, ],
         'MetaTests',         # core
         'PodSyntaxTests',    # core
         (
@@ -376,6 +395,7 @@ sub configure {
         'MetaYAML'
         ,    # core : Helps avoid kwalitee croaks and supports older systems
         'MetaJSON',    # core
+        'TravisYML',
         [
             'ChangelogFromGit::CPAN::Changes' => {
                 tag_regexp             => $self->tag_regexp,
@@ -384,15 +404,19 @@ sub configure {
                 file_name              => 'Changes',
             }
         ],
-        [
-            'ChangelogFromGit::Debian' => {
-                tag_regexp             => $self->tag_regexp,
-                parse_version_from_tag => 1,
-                file_name              => 'debian/changelog',
-                maintainer_name        => 'Shantanu Bhadoria',
-                maintainer_email       => 'shantanu@cpan.org',
-            }
-        ],
+        (
+            $self->compile_for_debian
+            ? [
+                'ChangelogFromGit::Debian' => {
+                    tag_regexp             => $self->tag_regexp,
+                    parse_version_from_tag => 1,
+                    file_name              => 'debian/changelog',
+                    maintainer_name        => 'Shantanu Bhadoria',
+                    maintainer_email       => 'shantanu@cpan.org',
+                }
+              ]
+            : ()
+        ),
         (
             $self->compile_for_debian
             ? [
@@ -414,13 +438,6 @@ sub configure {
             : $self->makemaker
         ),             # core
 
-        # copy files from build back to root for inclusion in VCS
-        [
-            CopyFilesFromBuild => {
-                copy => qw[META.yml Changes],
-            }
-        ],
-
         # manifest -- must come after all generated files
         'Manifest',    # core
 
@@ -430,8 +447,9 @@ sub configure {
             ? ()
             : [
                 'Git::Check' => {
-                    allow_dirty =>
-                      [qw/dist.ini Changes README.md README.pod META.yml/]
+                    allow_dirty => [
+                        qw/dist.ini Changes README.md README.pod META.yml META.json .travis.yml/
+                    ]
                 }
             ]
         ),
@@ -440,6 +458,18 @@ sub configure {
         'CheckExtraTests',
         'TestRelease',       # core
         'ConfirmRelease',    # core
+        (
+            $self->no_commitbuild
+            ? ()
+            : (
+                [
+                    'Git::CommitBuild' => 'Commit_to_build' => {
+                        release_branch  => 'build/%b',
+                        release_message => 'Release build of v%v (on %b)'
+                    }
+                ]
+            )
+        ),
 
         # release
         ( $self->fake_release ? 'FakeRelease' : 'UploadToCPAN' ),    # core
@@ -456,7 +486,7 @@ sub configure {
                 [
                     'Git::Commit' => 'Commit_Dirty_Files' => {
                         allow_dirty => [
-                            qw/dist.ini Changes README.md README.pod META.json META.yml/
+                            qw/dist.ini Changes README.md README.pod META.json META.yml .travis.yml/
                         ]
                     }
                 ],
@@ -466,9 +496,8 @@ sub configure {
 
         # bumps Changes
         [
-            'NextRelease' => {
-                format => '%n%v%n%n%t- %{yyyy-MM-dd HH:mm:ss VVVV}d%n',
-            },
+            'NextRelease' =>
+              { format => '%n%v%n%n%t- %{yyyy-MM-dd HH:mm:ss VVVV}d%n', },
         ],    # core (also munges files)
 
         (
@@ -510,7 +539,7 @@ Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -526,7 +555,7 @@ this is derived from like the one by David Golden.
 
 =head1 ATTRIBUTES
 
-=head2 no_git
+=head2 makemaker 
 
 makemaker attribute By default uses [MakeMaker::Awesome] This can be overriden by defining this attribute
 
@@ -538,6 +567,10 @@ Skip Default Makemaker option to add your own plugin for generating makefile
 
 no_git attribute
 
+=head2 no_commitbuild
+
+no_commitbuild attribute, do not create a build branch
+
 =head2 version_regexp 
 
 version_regexp attribute
